@@ -20,40 +20,41 @@ func NewDownloadCmd(f *cmdutil.Factory, runF func(*Options) error) *cobra.Comman
 	opts := &Options{}
 	downloadCmd := &cobra.Command{
 		Use:   "download [<file-path> | oci://<image-uri>] [--owner | --repo]",
-		Args:  cmdutil.MinimumArgs(1, "must specify file path or container image URI, as well as one of --owner or --repo"),
-		Short: "Download an artifact's Sigstore bundle(s) for offline use",
+		Args:  cmdutil.ExactArgs(1, "must specify file path or container image URI, as well as one of --owner or --repo"),
+		Short: "Download an artifact's attestations for offline use",
 		Long: heredoc.Docf(`
-			Download an artifact's attestations, aka Sigstore bundle(s), for offline use.
+			### NOTE: This feature is currently in beta, and subject to change.
+
+			Download attestations associated with an artifact for offline use.
 
 			The command requires either:
 			* a file path to an artifact, or
 			* a container image URI (e.g. %[1]soci://<image-uri>%[1]s)
-
-			(Note that if you provide an OCI URL, you must already be authenticated with
-			its container registry.)
+			  * (note that if you provide an OCI URL, you must already be authenticated with
+			its container registry)
 
 			In addition, the command requires either:
-			* the %[1]s--owner%[1]s flag (e.g. --owner github), or
 			* the %[1]s--repo%[1]s flag (e.g. --repo github/example).
-
-			The %[1]s--owner%[1]s flag value must match the name of the GitHub organization
-			that the artifact is associated with.
+			* the %[1]s--owner%[1]s flag (e.g. --owner github), or
 
 			The %[1]s--repo%[1]s flag value must match the name of the GitHub repository
-			that the artifact is associated with.
+			that the artifact is linked with.
 
-			Any associated Sigstore bundle(s) will be written to a file in the
+			The %[1]s--owner%[1]s flag value must match the name of the GitHub organization
+			that the artifact's linked repository belongs to.
+
+			Any associated bundle(s) will be written to a file in the
 			current directory named after the artifact's digest. For example, if the
 			digest is "sha256:1234", the file will be named "sha256:1234.jsonl".
 		`, "`"),
 		Example: heredoc.Doc(`
-			# Download Sigstore bundle(s) for a local artifact associated with a GitHub organization
+			# Download attestations for a local artifact linked with an organization
 			$ gh attestation download example.bin -o github
 
-			# Download Sigstore bundle(s) for a local artifact associated with a GitHub repository
+			# Download attestations for a local artifact linked with a repository
 			$ gh attestation download example.bin -R github/example
 
-			# Download Sigstore bundle(s) for an OCI image associated with a GitHub organization
+			# Download attestations for an OCI image linked with an organization
 			$ gh attestation download oci://example.com/foo/bar:latest -o github
 		`),
 		// PreRunE is used to validate flags before the command is run
